

#property indicator_chart_window

#property indicator_buffers 3

#property indicator_color1 Aqua
#property indicator_width1 3
#property indicator_color2 Blue
#property indicator_width2 2
#property indicator_color3 Red
#property indicator_width3 2


//+------------------------------------------------------------------+


input double ATR_Factor = 1.5;
input int MA_Period = 20;
input bool AlertPopup = false;
input bool Sound = false;
input bool Email = false;
input bool Mobile = false;

int ATR = 14;
string IndicatorName = "SuperLadder";

//+------------------------------------------------------------------+

double bufferLadder[], bufferUp[], bufferDn[];
double bufferDirection[];

//+------------------------------------------------------------------+

int init()
{
   
   IndicatorBuffers(4);
   
   SetIndexStyle(0, DRAW_LINE);
   SetIndexBuffer(0, bufferLadder);
   SetIndexStyle(1, DRAW_LINE);
   SetIndexBuffer(1, bufferUp);
   SetIndexStyle(2, DRAW_LINE);
   SetIndexBuffer(2, bufferDn);
   SetIndexBuffer(3, bufferDirection);
   
   return(0);

}

//+------------------------------------------------------------------+

int deinit()
{
   return(0);
}

//+------------------------------------------------------------------+

datetime dtLastTime = 0;

int start()
{
   double thisCCI;
   double dAtr=0.0;
   
   int limit, shift;
   int counted_bars=IndicatorCounted();
   //---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   limit=Bars-counted_bars;
   

   for (shift=limit-1; shift >= 0; shift--)
   {
      thisCCI = iCCI(NULL, 0, MA_Period, PRICE_TYPICAL, shift);
      dAtr = iATR(NULL, 0, ATR, shift);
      
     
      
      bufferDirection[shift]=0.0;
 

      if (thisCCI >= 0)
      {
         bufferLadder[shift] = Low[shift] - dAtr * ATR_Factor;
         if (bufferLadder[shift] < bufferLadder[shift + 1])
            bufferLadder[shift] = bufferLadder[shift + 1];
       
      }
      else
      {
            bufferLadder[shift] = High[shift] + dAtr * ATR_Factor;
            if (bufferLadder[shift] > bufferLadder[shift + 1])
               bufferLadder[shift] = bufferLadder[shift + 1];
               
      }
            

      if (bufferLadder[shift]>bufferLadder[shift+1]) bufferDirection[shift] = 1.0;
      if (bufferLadder[shift]<bufferLadder[shift+1]) bufferDirection[shift] = -1.0;    
      if (bufferLadder[shift]==bufferLadder[shift+1]) bufferDirection[shift] = bufferDirection[shift+1];        
      
      if (bufferDirection[shift]>0.0) bufferUp[shift]=bufferLadder[shift]-Point*2;
      if (bufferDirection[shift]<0.0) bufferDn[shift]=bufferLadder[shift]+Point*2;
      
   }
   
   
   /// Alert Process
   
      if (bufferDirection[1]!=bufferDirection[2] && dtLastTime!=Time[0])
      {
   
         dtLastTime = Time[0];
   
         double dLastDayClose = iClose(Symbol(),PERIOD_D1,1);
         double dUpDnPercent = NormalizeDouble( (Close[0] - dLastDayClose)/dLastDayClose * 100.0, 2);
         
         string strAlertMessage; 
         
   
        if (bufferDirection[1] > 0.0)
        {
            strAlertMessage = StringConcatenate(IndicatorName," Alert: ",Symbol(),"_",PeriodToString(Period())," UP");
      
            if (AlertPopup) 
               Alert(strAlertMessage);
            if (Sound&&AlertPopup)
               PlaySound("alert.wav");
            if (Email)
               SendMail(strAlertMessage,
                  "Current Price "+DoubleToStr(Close[0],Digits)+
                  "\nTime: " + TimeToStr(TimeCurrent(),TIME_DATE|TIME_SECONDS)
                  + "\nLast Day Close: " + DoubleToStr(dLastDayClose,Digits) 
                  + "\nChange: " + DoubleToStr(dUpDnPercent,2) + "%");
            if (Mobile)
               SendNotification(strAlertMessage);           
        }
        
        if (bufferDirection[1] < 0.0)
        {
            strAlertMessage = StringConcatenate(IndicatorName," Alert: ",Symbol(),"_",PeriodToString(Period())," DOWN");
      
            if (AlertPopup) 
               Alert(strAlertMessage);
            if (Sound&&AlertPopup)
               PlaySound("alert.wav");
            if (Email)
               SendMail(strAlertMessage,
                  "Current Price "+DoubleToStr(Close[0],Digits)+
                  "\nTime: " + TimeToStr(TimeCurrent(),TIME_DATE|TIME_SECONDS)
                  + "\nLast Day Close: " + DoubleToStr(dLastDayClose,Digits) 
                  + "\nChange: " + DoubleToStr(dUpDnPercent,2) + "%");
            if (Mobile)
               SendNotification(strAlertMessage);           
        }
      }
   
   return(0);
   
}


  
string PeriodToString (int imin)
{

   string strprd;

   switch (imin)
   {

   case (1):  
   strprd="M1"; 
   break;
   case (2):  
   strprd="M2"; 
   break;
   case (3):  
   strprd="M3"; 
   break;
   case (5):  
   strprd="M5"; 
   break;
   case (15):  
   strprd="M15"; 
   break;
   case (30):  
   strprd="M30"; 
   break;
   case (60):  
   strprd="H1"; 
   break;
   case (60*4):  
   strprd="H4"; 
   break;
   case (60*24):  
   strprd="D1"; 
   break;
   case (60*24*7):  
   strprd="W1"; 
   break;
   }

   return (strprd);

}


